==> jc-1.4.0.tar.gz: javax/imageio/stream/FileImageOutputStream.h <==
// public class javax.imageio.stream.FileImageOutputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 466606383ff2f2d8 javax_imageio_stream_FileImageOutputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileImageOutputStream_H_
#define _JC_javax_imageio_stream_FileImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$sub_refs	_jc_javax_imageio_stream_FileImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$refs	_jc_javax_imageio_stream_FileImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$nonrefs	_jc_javax_imageio_stream_FileImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$object	_jc_javax_imageio_stream_FileImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vmethods	_jc_javax_imageio_stream_FileImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vtable	_jc_javax_imageio_stream_FileImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vtype	_jc_javax_imageio_stream_FileImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$_init$538ee07130435a5e(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_java_io_File$object *);
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$_init$d89f2e0d09a08bf1(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_java_io_RandomAccessFile$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
extern jlong _jc_javax_imageio_stream_FileImageOutputStream$method$length$c5778ac730410d75(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_FileImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_FileImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$seek$d605bbca03fdd295(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jlong);
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jint);
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$length$c5778ac730410d75;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$seek$d605bbca03fdd295;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileImageOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
	jlong	(*length$c5778ac730410d75)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*seek$d605bbca03fdd295)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jlong);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_imageio_stream_FileImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_FileImageOutputStream$vmethods	javax_imageio_stream_FileImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageOutputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*file;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageOutputStream$refs {
    _jc_javax_imageio_stream_FileImageOutputStream$sub_refs	javax_imageio_stream_FileImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs	javax_imageio_stream_FileImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileImageOutputStream$object {
	_jc_javax_imageio_stream_FileImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileImageOutputStream$vtype _jc_javax_imageio_stream_FileImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileImageOutputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/FileImageOutputStream.h <==
// public class javax.imageio.stream.FileImageOutputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 466606383ff2f2d8 javax_imageio_stream_FileImageOutputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileImageOutputStream_H_
#define _JC_javax_imageio_stream_FileImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$sub_refs	_jc_javax_imageio_stream_FileImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$refs	_jc_javax_imageio_stream_FileImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$nonrefs	_jc_javax_imageio_stream_FileImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileImageOutputStream$object	_jc_javax_imageio_stream_FileImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vmethods	_jc_javax_imageio_stream_FileImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vtable	_jc_javax_imageio_stream_FileImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileImageOutputStream$vtype	_jc_javax_imageio_stream_FileImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$_init$538ee07130435a5e(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$_init$d89f2e0d09a08bf1(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_java_io_RandomAccessFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_javax_imageio_stream_FileImageOutputStream$method$length$c5778ac730410d75(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$seek$d605bbca03fdd295(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$length$c5778ac730410d75;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$seek$d605bbca03fdd295;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_FileImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileImageOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
	jlong	(*length$c5778ac730410d75)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*seek$d605bbca03fdd295)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jlong) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_FileImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_FileImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_FileImageOutputStream$vmethods	javax_imageio_stream_FileImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageOutputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*file;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageOutputStream$refs {
    _jc_javax_imageio_stream_FileImageOutputStream$sub_refs	javax_imageio_stream_FileImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_FileImageOutputStream$sub_nonrefs	javax_imageio_stream_FileImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileImageOutputStream$object {
	_jc_javax_imageio_stream_FileImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileImageOutputStream$vtype _jc_javax_imageio_stream_FileImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileImageOutputStream_H_ */
